<?php
/**
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the 
 * License for the specific language governing rights and limitations under the License.
 * 
 * The Original Code is Alchitect Site.
 * 
 * The Initial Developer of the Original Code is Darrell Brogdon.
 * Portions created by Darrell Brogdon are Copyright (C) 2002-2009 Darrell Brogdon.
 * All Rights Reserved.
 * 
 * Contributor(s): .
 * 
 * @package AlchitectSite
 */
/**
 * A controller for handling User Accounts
 */
class AdminController extends ASController
{
	public $pages_options = '';
	
	/**
	 * The constructor
	 *
	 * @access public
	 * @param ASPageRequest $PageRequest
	 */
	function __construct(ASPageRequest $PageRequest)
	{
		parent::__construct($PageRequest);
	}
	
	/**
	 * Handle page loads.
	 * 
	 * This method is called whenever a page is loaded.  It sets the 
	 * confirmation if any, if the action is 'edit' it ensures that an ID is 
	 * present, and fetches the data for the page if 
	 * <pre>$page_data['url_data'][2]</pre> is found.
	 * 
	 * @access public
	 * @param Array The page data.
	 * @return Void
	 */
	function handlePageLoad($page_data)
	{
		$directory		= dir(ALCHITECT_BASE_ROOT . '/pages');
		$ignore_files	= array
		(
			'admin'
		  , 'file_not_found.php'
		  , 'notice.php'
		  , 'home.php'
		  , 'template.html.php'
		  , 'template.xml.php'
		  , 'user_account'
		);

		while (false !== ($entry = $directory->read()))
		{
			if (preg_match('/^\./', $entry) || in_array($entry, $ignore_files))
			{
				continue;
			}

			$this->pages_options .= sprintf('<option value="%s">%s</option>', $entry, $entry);
		}

		$directory->close();
	}
	
	/**
	 * Handle HTTP POST requests with an 'insert' action
	 * 
	 * If the insert is successful then the user is redirected to the URL found
	 * in ASPageRequest::pathToAction().  Otherwise an error is set.
	 *
	 * @access public
	 * @param Array The data to be inserted.
	 * @return Boolean
	 * @see genericQuery()
	 * @see ASPageRequest::pathToAction()
	 */
	public function handleJSONInsert($insert_data)
	{
		return $this->createPage($insert_data['page_name'], $_FILES['from_file']['size'] > 0);
	}
	
	public function handlePostInsert($insert_data)
	{
		return $this->handleJSONInsert($insert_data);
	}
	
	/**
	 * Create a new Alchitect page.
	 */
	private function createPage($page_name, $process_uploaded_file=false)
	{
		$controller_name	= ASString::camelize($page_name);
		$controller_file	= ALCHITECT_BASE_ROOT . "/controllers/{$controller_name}Controller.php";
		$javascripts_dir	= ALCHITECT_BASE_ROOT . "/javascripts/{$page_name}";
		$javascripts_file	= ALCHITECT_BASE_ROOT . "/javascripts/{$page_name}/{$page_name}.js";
		$model_file			= ALCHITECT_BASE_ROOT . "/models/{$controller_name}Model.php";
		$page_dir			= ALCHITECT_BASE_ROOT . "/pages/{$page_name}";
		$page_file			= ALCHITECT_BASE_ROOT . "/pages/{$page_name}/default.php";
		$stylesheet_file	= ALCHITECT_BASE_ROOT . "/stylesheets/{$page_name}.css";
		
		// Make sure we're not going to overwrite anything
		if (file_exists($page_dir)
		||  file_exists($controller_file)
		||  file_exists($model_file)
		||  file_exists($stylesheet_file)
		||  file_exists($javascripts_dir)
		||  file_exists($javascripts_file))
		{
			return false;
		}
		
		// Create the page directory
		mkdir($page_dir);
		
		// If the user uploaded a pre-written HTML file then prepend the contents of the
		// 'head.php' template to it and use that as the 'default.php' file.  Otherwise
		// use the 'default.php' template.
		if (true === $process_uploaded_file)
		{
			file_put_contents($page_file, $this->processHeadPageTemplate($page_name));
		}
		else
		{
			file_put_contents($page_file, $this->processDefaultPageTemplate($page_name));
		}
		
		// Create the Controller
		file_put_contents($controller_file, $this->processControllerTemplate($controller_name));
		
		// Create the Model
		file_put_contents($model_file, $this->processModelTemplate($controller_name, $page_name));
		
		// Create the Stylesheet
		copy(ALCHITECT_BASE_ROOT . "/pages/admin/templates/home.css", $stylesheet_file);
		
		// Create the Javascript
		mkdir($javascripts_dir);
		copy(ALCHITECT_BASE_ROOT . "/pages/admin/templates/javascript.js", $javascripts_file);
		
		// If the user uploaded an HTML file then process it for input fields which we
		// then use to create a table in the db.
		if (true === $process_uploaded_file)
		{
			$InputProcessor	= new ASInputProcessor(file_get_contents($_FILES['from_file']['tmp_name']), $page_name);
			$sql			= $InputProcessor->sql();
			
			$this->Model->handle()->query($sql);
		}
		
		return true;
	}
	
	private function processDefaultPageTemplate($page_name)
	{
		$page_contents = file_get_contents(ALCHITECT_BASE_ROOT . "/pages/admin/templates/default.php");
		$page_contents = str_replace('@@PAGE_NAME@@', $page_name, $page_contents);
		
		return $page_contents;
	}
	
	private function processControllerTemplate($controller_name)
	{
		$controller_contents = file_get_contents(ALCHITECT_BASE_ROOT . "/pages/admin/templates/Controller.php");
		$controller_contents = str_replace('@@PAGE_CLASS_NAME@@', $controller_name, $controller_contents);
		
		return $controller_contents;
	}
	
	private function processHeadPageTemplate($page_name)
	{
		$uploaded_file_contents	= file_get_contents($_FILES['from_file']['tmp_name']);
		$page_head_contents		= file_get_contents(ALCHITECT_BASE_ROOT . "/pages/admin/templates/head.php");
		$page_head_contents		= str_replace('@@PAGE_NAME@@', $page_name, $page_head_contents);
			
		return $page_head_contents . "\n" . $uploaded_file_contents;
	}
	
	private function processModelTemplate($controller_name, $page_name)
	{
		$model_contents = file_get_contents(ALCHITECT_BASE_ROOT . "/pages/admin/templates/Model.php");
		$model_contents = str_replace('@@PAGE_CLASS_NAME@@', $controller_name, $model_contents);
		$model_contents = str_replace('@@PAGE_NAME@@', $page_name, $model_contents);
		
		return $model_contents;
	}
}
?>