<?php
/**
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the 
 * License for the specific language governing rights and limitations under the License.
 * 
 * The Original Code is Alchitect Core Server.
 * 
 * The Initial Developer of the Original Code is Darrell Brogdon.
 * Portions created by Darrell Brogdon are Copyright (C) 2002-2009 Darrell Brogdon.
 * All Rights Reserved.
 * 
 * Contributor(s): .
 * 
 * @package AlchitectUserAccountModule
 */
/**
 * A controller for handling User Accounts
 */
class UserAccountController extends ASController  {
	private $data = null;
	
	/**
	 * The constructor
	 *
	 * @access public
	 * @param ASPageRequest $PageRequest
	 */
	function __construct(ASPageRequest $PageRequest) {
		parent::__construct($PageRequest);
		
		$this->initModel
		(
			new UserAccountModel($this->PageRequest->pageName())
		);
	}
	
	/**
	 * 
	 */
	public function getAccountDataAsArray()
	{
		if (is_null($this->data))
		{
			$user_id = 
			(
				'' == $this->PageRequest->id()
			  ? ASSession::valueForKey('user_id')
			  : $this->PageRequest->id()
			);
			
			$this->Model->setAttrib('id', $user_id);
			
			if ($this->Model->get())
			{
				$this->data = $this->Model->getData();
			}
			else
			{
				$this->data = array();
			}
		}
		
		return $this->data;
	}
	
	/**
	 * Handle JSON Insert request and md5() the password before it gets 
	 * inserted into the database.  Also makes the Model ignore the 
	 * 'last_modified_by' field.
	 *
	 * @access public
	 * @param Array $info_data
	 * @return Boolean
	 * @see genericQuery()
	 */
	public function handleJSONInsert($info_data)
	{
		$old_password			= $info_data['password'];
		$info_data['password']	= md5($info_data['password']);
		$info_data['is_admin']	= (int)0;
		
		$this->Model->setIgnoredAttrib('last_modified_by');
		
		if (parent::handleJSONInsert($info_data))
		{
			// Set the $info_data password back to the non-hashed version so it
			// can be properly compared in handleJSONLogin().
			$info_data['password'] = $old_password;
			
			return $this->handleJSONLogin($info_data);
		}
			
		ASLog::instance()->debug("Insert returning false");
		
		return false;
	}
	
	/**
	 * Handle JSON Update request and md5() the password before it gets 
	 * inserted into the database.
	 */
	public function handleJSONUpdate($info_data)
	{
		$info_data['password']			= md5($info_data['password']);
		$info_data['last_modified_on']	= date('Y-m-d H:i:s');
						
		return parent::handleJSONUpdate($info_data);
	}
	
	/**
	 * Handle JSON Login request.
	 *
	 * @access public
	 * @param Array $info_data
	 * @return Boolean
	 * @see genericQuery()
	 */
	public function handleJSONLogin($info_data)
	{
		$info_data['password'] = md5($info_data['password']);
		
		$this->Model->setAttrib('email_address', $info_data['email_address']);
		
		if ($this->Model->get())
		{	
			$data = $this->Model->getData();
	
			if (is_array($data) && sizeof($data) && isset($data['password']))
			{
				if ($info_data['password'] == $data['password'])
				{
					ASSession::saveUserData(array
					(
						'user_id'	=> $data['id']
					  , 'username'	=> $data['email_address']
					));
									
					return array
					(
						'user_id'		=> $data['id']
					  , 'email_address'	=> $data['email_address']
					  , 'auth_key'		=> ASSession::authKey()
					);
				}
			}
		}
		
		return false;
	}
	
	/**
	 * Handle page loads.
	 */
	public function handlePageLoad($info_data)
	{		
		$info_data['url_parts'][ASPageRequest::AS_PAGE_REQ_URL_PART_ID] =
			ASSession::valueForKey('user_id');
		$action = $this->PageRequest->action();
			
		if ('edit' == $action || 'list' == $action)
		{
			if (is_null(ASSession::authUser()))
			{
				header('Location: ' . BASE_HREF . '/app/user_account/login');
			}
			else
			{
				$this->PageRequest->setPageData($this->getAccountDataAsArray());
			}
		}
		else
		{
			parent::handlePageLoad($info_data);
		}
	}
	
	/**
	 * Handle HTTP POST requests
	 * 
	 * @access public
	 * @return Mixed
	 */
	public function handlePost()
	{
		$_POST['password'] = md5($_POST['password']);
		
		$this->Model->setAttrib('email_address', $_POST['email_address']);
		$this->Model->get();
		
		$data = $this->Model->getData();
		
		if (is_array($data) && sizeof($data) && isset($data['password']))
		{
			if ($info_data['password'] == $data['password'])
			{
				ASSession::saveUserData(array
				(
					'user_id'	=> $data['id']
				  , 'username'	=> $data['email_address']
				));
				
				return array
				(
					'user_id'=>$data['id']
				  , 'email_address'=>$data['email_address']
				  , 'auth_key'=>ASSession::authKey()
				);
			}
		}
		
		return false;
	}

	/**
	 * Returns a boolean value based on whether the user, if one is present,
	 * is an admin.
	 */
	public function userIsAnAdmin()
	{
		if (ASSession::valueForKey('user_id'))
		{
			if (is_null($this->data))
			{
				$this->Model->setAttrib('id', ASSession::valueForKey('user_id'));
				
				$this->data = parent::getDataAsArray();
			}
					
			return (boolean)$this->data['is_admin'];
		}
		
		return false;
	}
}
?>