<?php
/**
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the 
 * License for the specific language governing rights and limitations under the License.
 * 
 * The Original Code is Alchitect Core Server.
 * 
 * The Initial Developer of the Original Code is Darrell Brogdon.
 * Portions created by Darrell Brogdon are Copyright (C) 2002-2009 Alchisoft, LLC
 * All Rights Reserved.
 * 
 * Contributor(s): .
 * 
 * @package AlchitectCoreServer
 */
class ASInputProcessor
{
	private $doc				= null;
	private $checkboxes			= null;
	private $checkbox_fields	= array();
	private $filename			= null;
	private $passwords			= null;
	private $password_fields	= array();
	private $radios				= null;
	private $radio_fields		= array();
	private $selects			= null;
	private $select_fields		= array();
	private $table_name			= null;
	private $textareas			= null;
	private $textarea_fields	= array();
	private $texts				= null;
	private $text_fields		= array();
	private $xpath				= null;
	
	public function __construct($html, $table_name)
	{
		$this->table_name	= $table_name;
		$this->doc			= new DOMDocument();
		
		$this->doc->loadHTML($html);
		
		$this->xpath		= new DOMXpath($this->doc);
		$this->checkboxes	= $this->xpath->query("//input[@type='checkbox']");
		$this->passwords	= $this->xpath->query("//input[@type='password']");
		$this->radios		= $this->xpath->query("//input[@type='radio']");
		$this->selects		= $this->xpath->query("//select");
		$this->textareas	= $this->xpath->query("//textarea");
		$this->texts		= $this->xpath->query("//input[@type='text']");
		
		$this->processCheckboxFields();
		$this->processPasswordFields();
		$this->processRadioFields();
		$this->processSelectFields();
		$this->processTextFields();
		$this->processTextareaFields();
	}
	
	private function processCheckboxFields()
	{
		for ($x=0,$y=$this->checkboxes->length; $x<$y; ++$x)
		{
			$this->checkbox_fields[] = new ASCheckboxFieldProcessor($this->checkboxes->item($x));
		}		
	}
	
	private function processPasswordFields()
	{
		for ($x=0,$y=$this->passwords->length; $x<$y; ++$x)
		{
			if (preg_match('/confirm/', $this->passwords->item($x)->getAttribute('name')))
			{
				continue;
			}
			
			$this->password_fields[] = new ASPasswordFieldProcessor($this->passwords->item($x));
		}		
	}
	
	private function processRadioFields()
	{
		for ($x=0,$y=$this->radios->length; $x<$y; ++$x)
		{
			$this->radio_fields[$this->radios->item($x)->getAttribute('name')][]
				= new ASRadioFieldProcessor($this->radios->item($x));
		}
	}
	
	private function processSelectFields()
	{
		for ($x=0,$y=$this->selects->length; $x<$y; ++$x)
		{
			$this->select_fields[] = new ASSelectFieldProcessor($this->selects->item($x));
		}
	}
		
	private function processTextareaFields()
	{
		for ($x=0,$y=$this->textareas->length; $x<$y; ++$x)
		{
			$this->textarea_fields[] = new ASTextareaFieldProcessor($this->textareas->item($x));
		}		
	}
		
	public function sql()
	{		
		$sql = "CREATE TABLE " . $this->table_name . " (\n"
			 . "\tid char(36) NOT NULL default '00000000-0000-0000-0000-000000000000',\n";
		
		foreach ($this->checkbox_fields as $CheckboxField)
		{
			$sql .= $CheckboxField->sql();
		}
		
		foreach ($this->text_fields as $TextField)
		{
			$sql .= $TextField->sql();
		}
		
		foreach ($this->password_fields as $PasswordField)
		{
			$sql .= $PasswordField->sql();
		}
		
		if (sizeof($this->radio_fields))
		{
			foreach ($this->radio_fields as $key=>$vals)
			{
				$sql .= "\t" . $key ." enum(";
				
				for ($x=0,$y=sizeof($vals); $x<$y; ++$x)
				{
					$RadioField = $vals[$x];
					$delim = ($x<($y - 1) ? ', ' : '');
					$sql .= "'{$RadioField->value}'{$delim}";
				}
				
				$sql .= "),\n";
			}
		}
		
		foreach ($this->select_fields as $SelectField)
		{
			$sql .= $SelectField->sql();
		}

		foreach ($this->textarea_fields as $TextareaField)
		{
			$sql .= $TextareaField->sql();
		}
					
		$sql .= "\tcreated_on datetime,\n"
			  . "\tPRIMARY KEY (id)\n)";
			
		return $sql;
	}
	
	private function processTextFields()
	{
		for ($x=0,$y=$this->texts->length; $x<$y; ++$x)
		{
			$this->text_fields[] = new ASTextFieldProcessor($this->texts->item($x));
		}		
	}
}
?>