<?php
/**
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the 
 * License for the specific language governing rights and limitations under the License.
 * 
 * The Original Code is Alchitect Core Server.
 * 
 * The Initial Developer of the Original Code is Darrell Brogdon.
 * Portions created by Darrell Brogdon are Copyright (C) 2002-2009 Alchisoft, LLC
 * All Rights Reserved.
 * 
 * Contributor(s): .
 * 
 * @package AlchitectCoreServer
 */
/**
 * An implementation of ActiveRecordLoader for MySQL databases.
 * 
 * @author Darrell Brogdon <darrell@brogdon.net>
 * @copyright (c)2002-2009 Alchisoft, LLC.
 * @package AlchitectCoreServer
 *
 */
class ASMySQLLoader implements ASActiveRecordLoader
{
	/**
	 * MySQL field loader.
	 * 
	 * This method uses MySQL-specific queries to load the fields for ActiveRecord.
	 *
	 * @access public
	 * @param String $database The name of the database
	 * @param String $table The name of the table
	 * @param Resource $dbh A resource to the database handle for PDO
	 * @return Array
	 */
	public function loadFields($database, $table, $dbh)
	{
		$sql    = "SHOW FULL COLUMNS FROM {$database}.{$table}";		
		$res    = $dbh->query($sql);
		$fields = array();
		
		if (false == is_object($res))
		{
			throw new Exception("Unable to load fields for {$database}.{$table}");
		}

		foreach ($res->fetchAll() as $row)
		{			
			$row   = (object)$row;
			$field = new ASActiveRecordField();

			$field->setName($row->Field);
			
			if ('' != $row->Comment)
			{
				// Validation
				$matches = array();
				
				preg_match('/alchitect\(validate:(\w*)\)/', $row->Comment, $matches);
				
				if (is_array($matches) && 2 == sizeof($matches))
				{
					$field->setValidationRule(strtolower($matches[1]));
				}
				
				// Sanitization
				$matches = array();
				
				preg_match('/alchitect\(sanitize:(\w*)\)/', $row->Comment, $matches);
				
				if (is_array($matches) && 2 == sizeof($matches))
				{
					$field->setSanitizationRule(strtolower($matches[1]));
				}
			}
			
			if (strstr($row->Field, '_id'))
			{
				$field->setForeignKey();
			}

			$types = explode("(", $row->Type);

			if (count($types) > 1)
			{
				$field->setType($types[0]);
				$field->setSize((int)$types[1]);
			}
			else
			{
				$field->setType($row->Type);
				$field->setSize(false);
			}
			
			if ($row->Key == "PRI")
			{
				$field->setPrimary();
			}
			
			$fields[] = $field;
		}
		
		return $fields;
	}
}
?>