<?php
/**
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the 
 * License for the specific language governing rights and limitations under the License.
 * 
 * The Original Code is Alchitect Core Server.
 * 
 * The Initial Developer of the Original Code is Darrell Brogdon.
 * Portions created by Darrell Brogdon are Copyright (C) 2002-2009 Alchisoft, LLC
 * All Rights Reserved.
 * 
 * Contributor(s): .
 * 
 * @package AlchitectCoreServer
 */
/**
 * ASObserver
 * 
 * Interface for implementing the Observer pattern.
 *
 * @author Darrell Brogdon <darrell@brogdon.net>
 * @copyright (c)2002-2009 Alchisoft, LLC
 * @package AlchitectCoreServer
 * @version $Id$
 */
interface ASObserver
{
	/**
	 * Add a new Observable object to the stack.
	 *
	 * @access public
	 * @param Observable $observer
	 */
    public function addObserver(ASObservable $observer);
    
    /**
     * Remove an existing Observable object from the stack.
     *
     * @access public
     * @param String $observer
     */
    public function removeObserver($observer);
    
    /**
     * Notify all Observables of an event.
     *
     * @access public
     * @param Mixed $info
     */
    function notifyObservables($info);
}

/**
 * ASObservable
 * 
 * Interface for implementing the Observer/Observable pattern.
 *
 * @author Darrell Brogdon <darrell@brogdon.net>
 * @copyright (c)2002-2009 Alchisoft, LLC
 * @package AlchitectCoreServer
 * @version $Id$
 */
interface ASObservable
{
	/**
	 * Receive an event from an Observer.
	 *
	 * @param Mixed $info
	 */
    function updateFromObserver($info);
}
?>