<?php
/**
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the 
 * License for the specific language governing rights and limitations under the License.
 * 
 * The Original Code is Alchitect Core Server.
 * 
 * The Initial Developer of the Original Code is Darrell Brogdon.
 * Portions created by Darrell Brogdon are Copyright (C) 2002-2009 Alchisoft, LLC
 * All Rights Reserved.
 * 
 * Contributor(s): .
 * 
 * @package AlchitectCoreServer
 */
/**
 * An implementation of ActiveRecordLoader for PostgreSQL databases.
 * 
 * @author Darrell Brogdon <darrell@brogdon.net>
 * @since Wed Jul 12 14:13:05 MDT 2006 14:13:05
 * @copyright (c)2006 Alchisoft, LLC.
 * @package AlchitectCoreServer
 *
 */
class ASPgSQLLoader implements ASActiveRecordLoader
{
	/**
	 * PostgreSQL field loader.
	 * 
	 * This method uses PostgreSQL-specific queries to load the fields for ActiveRecord.
	 *
	 * @access public
	 * @param String $database The name of the database
	 * @param String $table The name of the table
	 * @param Resource $dbh A resource to the database handle for PDO
	 * @return Array
	 */
	function loadFields($database, $table, $dbh)
	{
		$fields = array();
		$sql    = "
SELECT		a.attname AS field,
			t.typname AS type,
CASE WHEN 	a.attstorage = 'p' AND a.attnotnull = 't' AND a.atthasdef = 't' AND t.typname LIKE 'int%'
	THEN 	't'
	ELSE 	'f'
END AS 		is_primary,
CASE WHEN 	a.attlen >= 0
	THEN	a.attlen
	ELSE	NULL
END AS		size
FROM 		pg_class c,
			pg_attribute a,
			pg_type t
WHERE 		c.relname = '${table}'
AND 		a.attnum > 0 
AND 		a.attrelid = c.oid
AND 		a.atttypid = t.oid
ORDER BY	a.attnum";
		$res    = $dbh->query($sql);
		
		foreach ($res->fetchAll() as $row)
		{
			$row   = (object)$row;
			$field = new ActiveRecordField();

			$field->setName($row->field);
			$field->setType(preg_replace('/\d*/', '', $row->type));
			$field->setSize($row->size);
			
			if ($row->is_primary == 't')
			{
				$field->setPrimary();
			}
			
			$fields[] = $field;
		}
		
		return $fields;
	}
}
?>