<?php
/**
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the 
 * License for the specific language governing rights and limitations under the License.
 * 
 * The Original Code is Alchitect Core Server.
 * 
 * The Initial Developer of the Original Code is Darrell Brogdon.
 * Portions created by Darrell Brogdon are Copyright (C) 2002-2009 Alchisoft, LLC.
 * All Rights Reserved.
 * 
 * Contributor(s): .
 * 
 * @package AlchitectCoreServer
 */
/**
 * Exception to be thrown when the user submits a form and the contents of a 
 * field fails validation.
 *
 * @author Darrell Brogdon <darrell@brogdon.net>
 * @copyright (c)2002-2009 Alchisoft, LLC
 * @package AlchitectCoreServer
 * @version $Id: $
 */
class ASValidationException extends ASException
{
	protected $message	= "'%VALUE%' is not a valid %TYPE%";
	protected $code		= 0x3ee;
	
	/**
	 * The constructor
	 * 
	 *@param String The value that failed validation. 
	 *@param String The validation type.
	 */
	public function __construct($value, $type)
	{
		$message = str_replace
		(
			'%VALUE%'
		  , $value
		  , str_replace('%TYPE%', $this->processType($type), $this->message)
		);
		
		parent::__construct($message, $this->code);
	}
	
	/**
	 * Process the validation type into a more readable variation.
	 * 
	 * @access private
	 * @param String The type
	 * @return String
	 */
	private function processType($type)
	{
		switch ($type)
		{
			case 'email':
			{
				$type = 'Email Address';
				break;
			}
			case 'float':
			case 'int':
			{
				$type = 'Number';
				break;	
			}
			case 'ip':
			{
				$type = 'IP Address';
				break;
			}
			case 'url':
			{
				$type = 'URL';
				break;
			}
		}
		
		return $type;
	}
}
?>